import pylab as P
import numpy as N

#==========================
# To benchmark imshow alone
#==========================
def generate_data_2d(fr, nwin, hop, len):
    nframes = 1.0 * fr / hop * len
    return N.random.randn(nframes, nwin)

def generate_data_1d(fr, len):
    nsamples    = len * fr
    return N.random.randn(nsamples)

def bench_imshow(fr, nwin, hop, len, show = True):
    data    = generate_data_2d(fr, nwin, hop, len)
    P.imshow(data)
    if show:
        #a   = P.gcf()
        P.show()
        P.close()

def bench_specgram(fr, nwin, hop, len, show = True):
    data    = generate_data_1d(fr, len)
    h       = P.specgram(data, nwin, fr, noverlap = hop)
    if show:
        P.show()

def bench_imshow_show():
    # 2 minutes (120 sec) of sounds @ 8 kHz with 256 samples with 50 % overlap
    bench_imshow(8000, 256, 128, 120, show = True)

def bench_imshow_noshow():
    # 2 minutes (120 sec) of sounds @ 8 kHz with 256 samples with 50 % overlap
    bench_imshow(8000, 256, 128, 120, show = False)

if __name__ == '__main__':
    # show case
    import hotshot, hotshot.stats
    profile_file    = 'imshow_show.prof'
    prof    = hotshot.Profile(profile_file, lineevents=1)
    prof.runcall(bench_imshow_show)
    p = hotshot.stats.load(profile_file)
    print p.sort_stats('cumulative').print_stats(20)
    prof.close()

    # noshow case
    import hotshot, hotshot.stats
    profile_file    = 'imshow_noshow.prof'
    prof    = hotshot.Profile(profile_file, lineevents=1)
    prof.runcall(bench_imshow_noshow)
    p = hotshot.stats.load(profile_file)
    print p.sort_stats('cumulative').print_stats(20)
    prof.close()
